Name:           radare2
Summary:        The reverse engineering framework
Version:        5.8.8
%global         baserelease     2.2
URL:            https://radare.org/
VCS:            https://github.com/radareorg/radare2



%bcond_without     releasetag

%global         gituser         radareorg
%global         gitname         radare2

%global         gitdate         20230608
%global         commit          ea7f0356519884715cf1d5fba16042bac72b2df5
%global         shortcommit     %(c=%{commit}; echo ${c:0:7})


%if %{with releasetag}
Release:    1%{?dist}
Source0:        https://github.com/%{gituser}/%{gitname}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
%else
Release:    1%{?dist}
Source0:        https://github.com/%{gituser}/%{gitname}/archive/%{commit}/%{name}-%{commit}.tar.gz#/%{name}-%{version}-git%{gitdate}-%{shortcommit}.tar.gz
%endif

Patch1:         radare2-5.6.6-use_openssl.patch
Patch3:         radare2-5.7.6-use_magic.patch
Patch4:         radare2-5.6.6-use_lz4.patch

License:        LGPLv3+ and GPLv2+ and BSD and MIT and ASL 2.0 and MPLv2.0 and zlib


BuildRequires:  sed
BuildRequires:  gcc
BuildRequires:  meson
BuildRequires:  ninja-build
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libxxhash)
BuildRequires:  pkgconfig(libzip)

BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(capstone) >= 3.0.4
BuildRequires:  pkgconfig(libuv)
BuildRequires:  pkgconfig(openssl)

BuildRequires:  file-devel
BuildRequires:  bzip2-devel
BuildRequires:  python3
BuildRequires:  xxhash

Requires:       %{name}-common = %{version}-%{release}








Provides:       bundled(spp) = 1.2.0

Provides:       bundled(sdb) = 1.8.6

Provides:       bundled(js0n) = 2018

Provides:       bundled(openbsdregex) = 1.11

Provides:       bundled(tcc) = 0.9.26

Provides:       bundled(binutils) = 2.13

Provides:       bundled(vavrdisasm) = 1.6

Provides:       bundled(grub2) = 1.99~beta0

Provides:       bundled(ptrace-wrap) = 20181018

Provides:       bundled(tree-sitter) = 0.17.2

Provides:       bundled(mpc) = 0.8.7

Provides:       bundled(yxml) = 20201108


%description
The radare2 is a reverse-engineering framework that is multi-architecture,
multi-platform, and highly scriptable.  Radare2 provides a hexadecimal
editor, wrapped I/O, file system support, debugger support, diffing
between two functions or binaries, and code analysis at opcode,
basic block, and function levels.


%package devel
Summary:        Development files for the radare2 package
Requires:       %{name} = %{version}-%{release}
Requires:       file-devel
Requires:       openssl-devel

%description devel
Development files for the radare2 package. See radare2 package for more
information.


%package common
Summary:        Arch-independent SDB files for the radare2 package
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description common
Arch-independent SDB files used by radare2 package. See radare2 package for more
information


%prep
%if %{with releasetag}
%autosetup -p 1 -n %{gitname}-%{version}
%else
%autosetup -p 1 -n %{gitname}-%{commit}
sed -i -e "s|%{version}-git|%{version}|g;" configure configure.acr
%endif
rm -rf shlr/zip/{zip,zlib,include}

rm -rf shlr/lz4/{deps.mk,LICENSE,lz4.*,Makefile,README.md}
rm -f libr/hash/xxhash.c libr/hash/xxhash.h
awk 'BEGIN {p=1} /#if USE_LIB_MAGIC/ {p=2; next} p==2 && /#else/ {p=0} p>0 {print}' libr/magic/magic.c > libr/magic/magic.c.stripped
awk 'BEGIN {p=1} /#if !USE_LIB_MAGIC/ {p=0; next} p==2 && /#else/ {p=0} p>0 {print}' libr/magic/ascmagic.c > libr/magic/ascmagic.c.stripped
rm -rf libr/magic/*.c
mv libr/magic/magic.c.stripped libr/magic/magic-libmagic.c
mv libr/magic/ascmagic.c.stripped libr/magic/ascmagic-libmagic.c

rm -rf ./shlr/www/*



%build

%meson \
    -Duse_sys_magic=true \
    -Duse_sys_zip=true \
    -Duse_sys_zlib=true \
    -Duse_sys_lz4=true \
    -Duse_sys_xxhash=true \
    -Duse_ssl=true \
    -Duse_libuv=true \
    -Duse_sys_capstone=true \
    -Denable_tests=false \
    -Denable_r2r=false \
    -Dwant_threads=false     # multithreading doesn't work well with Iaito package
%meson_build


%install
%meson_install
mkdir -p %{buildroot}/%{_datadir}/%{name}/%{version}/www
rm %{buildroot}/%{_datadir}/doc/%{name}/fortunes.fun

mkdir -p %{buildroot}%{_libdir}/%{name}/%{version}




%check


%files
%license COPYING COPYING.LESSER
%doc CONTRIBUTING.md DEVELOPERS.md README.md
%doc doc/3D/ doc/pdb/ doc/sandbox/
%doc doc/avr.md doc/brainfuck.md doc/calling-conventions.md doc/debug.md
%doc doc/esil.md doc/gdb.md doc/gprobe.md doc/intro.md doc/io.md doc/rap.md
%doc doc/siol.md doc/strings.md doc/windbg.md doc/yara.md
%doc %{_datadir}/doc/%{name}/fortunes.tips
%dir %{_datadir}/%{name}/%{version}/www
%{_bindir}/r*
%{_libdir}/libr_*.so.%{version}*
%{_libdir}/%{name}
%{_mandir}/man1/r*.1.*
%{_mandir}/man7/esil.7.*
%{_datadir}/zsh/site-functions/_r*


%files devel
%{_includedir}/libr
%{_libdir}/libr*.so
%{_libdir}/pkgconfig/*.pc


%files common
%{_datadir}/%{name}/%{version}/cons
%{_datadir}/%{name}/%{version}/fcnsign
%{_datadir}/%{name}/%{version}/flag
%{_datadir}/%{name}/%{version}/format
%{_datadir}/%{name}/%{version}/hud
%{_datadir}/%{name}/%{version}/magic
%{_datadir}/%{name}/%{version}/opcodes
%{_datadir}/%{name}/%{version}/syscall
%{_datadir}/%{name}/%{version}/charsets
%dir %{_datadir}/%{name}
%dir %{_datadir}/doc/%{name}
%dir %{_datadir}/%{name}/%{version}


%changelog
* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.8.8-1
- initial build
